## MDC
::: pybes3.detectors.identify.check_mdc_id
::: pybes3.detectors.identify.mdc_id_to_wire
::: pybes3.detectors.identify.mdc_id_to_layer
::: pybes3.detectors.identify.mdc_id_to_is_stereo
::: pybes3.detectors.identify.get_mdc_id

## TOF
::: pybes3.detectors.identify.check_tof_id
::: pybes3.detectors.identify.tof_id_to_part
::: pybes3.detectors.identify.tof_id_to_end
::: pybes3.detectors.identify.tof_id_to_scint_layer
::: pybes3.detectors.identify.tof_id_to_scint_phi
::: pybes3.detectors.identify.tof_id_to_mrpc_endcap
::: pybes3.detectors.identify.tof_id_to_mrpc_module
::: pybes3.detectors.identify.tof_id_to_mrpc_strip
::: pybes3.detectors.identify.get_tof_scint_id
::: pybes3.detectors.identify.get_tof_mrpc_id

## EMC
::: pybes3.detectors.identify.check_emc_id
::: pybes3.detectors.identify.emc_id_to_module
::: pybes3.detectors.identify.emc_id_to_theta
::: pybes3.detectors.identify.emc_id_to_phi
::: pybes3.detectors.identify.get_emc_id

# MUC
::: pybes3.detectors.identify.check_muc_id
::: pybes3.detectors.identify.muc_id_to_part
::: pybes3.detectors.identify.muc_id_to_segment
::: pybes3.detectors.identify.muc_id_to_layer
::: pybes3.detectors.identify.muc_id_to_strip
::: pybes3.detectors.identify.muc_id_to_gap
::: pybes3.detectors.identify.muc_id_to_strip
::: pybes3.detectors.identify.get_muc_id

# CGEM
::: pybes3.detectors.identify.check_cgem_id
::: pybes3.detectors.identify.cgem_id_to_layer
::: pybes3.detectors.identify.cgem_id_to_sheet
::: pybes3.detectors.identify.cgem_id_to_strip
::: pybes3.detectors.identify.cgem_id_to_is_x_strip
::: pybes3.detectors.identify.get_cgem_id

# Parse methods
!!! note
    Parse methods will always parse all available information.
    If performance is a concern, use the individual methods above.

::: pybes3.detectors.identify.parse_mdc_id
::: pybes3.detectors.identify.parse_tof_id
::: pybes3.detectors.identify.parse_emc_id
::: pybes3.detectors.identify.parse_muc_id
::: pybes3.detectors.identify.parse_cgem_id
